==> cybox-2.1.0.4.zip: cybox-2.1.0.4/cybox/common/__init__.py <==
# Copyright (c) 2014, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

"""
cybox.common package (CybOX Common)
===================================

The :py:mod:`cybox.common` module contains classes needed to implement the
types found in the CybOX Common schema (cybox_common.xsd).  Although the
implementation is spread between different modules within the ``cybox.common``
package, types should be imported directly from this module in case the
implementations are reorganized in the future.

In other words, do this:

    from cybox.common import String

rather than:

    from cybox.common.properties import String

"""

from __future__ import absolute_import

from .attribute_groups import DEFAULT_DELIM, PatternFieldGroup
from .properties import *
from .vocabs import VocabString

from .data_segment import DataSegment, DataSize
from .datetimewithprecision import DateTimeWithPrecision, DateWithPrecision
from .daterange import DateRange
from .digitalsignature import DigitalSignature, DigitalSignatureList
from .environment_variable import EnvironmentVariable, EnvironmentVariableList
from .hashes import Hash, HashList, HashName
from .object_properties import ObjectProperties
from .structured_text import StructuredText
from .time import Time
from .tools import ToolInformation, ToolInformationList, ToolType

from .byterun import ByteRun, ByteRuns
from .contributor import Contributor, Personnel
from .extracted_string import ExtractedString, ExtractedStrings
from .platform_specification import PlatformSpecification, PlatformIdentifier
from .measuresource import InformationSourceType, MeasureSource

from .extracted_features import ExtractedFeatures

==> cybox-2.1.0.7.zip: cybox-2.1.0.7/cybox/common/__init__.py <==
# Copyright (c) 2014, The MITRE Corporation. All rights reserved.
# See LICENSE.txt for complete terms.

"""
cybox.common package (CybOX Common)
===================================

The :py:mod:`cybox.common` module contains classes needed to implement the
types found in the CybOX Common schema (cybox_common.xsd).  Although the
implementation is spread between different modules within the ``cybox.common``
package, types should be imported directly from this module in case the
implementations are reorganized in the future.

In other words, do this:

    from cybox.common import String

rather than:

    from cybox.common.properties import String

"""

from __future__ import absolute_import

from .attribute_groups import DEFAULT_DELIM, PatternFieldGroup
from .properties import *
from .vocabs import VocabString

from .data_segment import DataSegment, DataSize
from .datetimewithprecision import DateTimeWithPrecision, DateWithPrecision
from .daterange import DateRange
from .digitalsignature import DigitalSignature, DigitalSignatureList
from .environment_variable import EnvironmentVariable, EnvironmentVariableList
from .hashes import Hash, HashList, HashName
from .object_properties import ObjectProperties, Property
from .structured_text import StructuredText
from .time import Time
from .tools import ToolInformation, ToolInformationList, ToolType

from .byterun import ByteRun, ByteRuns
from .contributor import Contributor, Personnel
from .extracted_string import ExtractedString, ExtractedStrings
from .platform_specification import PlatformSpecification, PlatformIdentifier
from .measuresource import InformationSourceType, MeasureSource

from .extracted_features import ExtractedFeatures
